Changelog — appypi 0.2.0 documentation

### Navigation

- index
- previous |
- appypi 0.2.0 documentation »

# Changelog

## 0.2 (2012-12-16)

- add requirement file handling
- full pylint-compliant cleaning, not perfect but better

## 0.1.4 (2012-11-17)

- fix setup.py, MANIFEST.IN for README.txt

## 0.1.3 (2012-11-15)

- fix README file for official release

## 0.1.2 (2012-11-15)

- fix setup.py and bootstrap, better documentation

## 0.1.1 (2012-11-11)

- fix erroneous MANIFEST

## 0.1 (2012-11-10)

- Initial release

### Navigation

- index
- previous |
- appypi 0.2.0 documentation »